@@ -252,6 +252,10 @@ class MincImageArrayProxy(object):
     def shape(self):
         return self._shape
 
+    @property
+    def ndim(self):
+        return len(self.shape)
+
     @property
     def is_proxy(self):
         return True
