@@ -2,6 +2,7 @@ import os
 import sys
 import unittest
 import tempfile
+import itertools
 import numpy as np
 
 from nose.tools import assert_equal, assert_raises, assert_true
@@ -91,11 +92,20 @@ class TestArraySequence(unittest.TestCase):
                       SEQ_DATA['data'])
 
     def test_creating_arraysequence_from_generator(self):
-        gen = (e for e in SEQ_DATA['data'])
-        check_arr_seq(ArraySequence(gen), SEQ_DATA['data'])
+        gen_1, gen_2 = itertools.tee((e for e in SEQ_DATA['data']))
+        seq = ArraySequence(gen_1)
+        seq_with_buffer = ArraySequence(gen_2, buffer_size=256)
+
+        # Check buffer size effect
+        assert_equal(seq_with_buffer.data.shape, seq.data.shape)
+        assert_true(seq_with_buffer._buffer_size > seq._buffer_size)
+
+        # Check generator result
+        check_arr_seq(seq, SEQ_DATA['data'])
+        check_arr_seq(seq_with_buffer, SEQ_DATA['data'])
 
         # Already consumed generator
-        check_empty_arr_seq(ArraySequence(gen))
+        check_empty_arr_seq(ArraySequence(gen_1))
 
     def test_creating_arraysequence_from_arraysequence(self):
         seq = ArraySequence(SEQ_DATA['data'])
@@ -152,6 +162,11 @@ class TestArraySequence(unittest.TestCase):
         seq.append(element)
         check_arr_seq(seq, [element])
 
+        # Append an empty array.
+        seq = SEQ_DATA['seq'].copy()  # Copy because of in-place modification.
+        seq.append([])
+        check_arr_seq(seq, SEQ_DATA['seq'])
+
         # Append an element with different shape.
         element = generate_data(nb_arrays=1,
                                 common_shape=SEQ_DATA['seq'].common_shape*2,
