@@ -38,7 +38,12 @@ from numpy.testing import (assert_array_equal, assert_array_almost_equal,
 from nose.tools import (assert_true, assert_false, assert_equal,
                         assert_raises)
 
-from ..testing import data_path, suppress_warnings, runif_extra_has
+from ..testing import (
+    clear_and_catch_warnings,
+    data_path,
+    runif_extra_has,
+    suppress_warnings,
+)
 
 from . import test_analyze as tana
 from . import test_spm99analyze as tspm
@@ -558,6 +563,22 @@ class TestNifti1PairHeader(tana.TestAnalyzeHeader, tspm.HeaderScalingMixin):
         assert_equal(hdr['slice_end'], 5)
         assert_array_almost_equal(hdr['slice_duration'], 0.1)
 
+        # Ambiguous case
+        hdr2 = self.header_class()
+        hdr2.set_dim_info(slice=2)
+        hdr2.set_slice_duration(0.1)
+        hdr2.set_data_shape((1, 1, 2))
+        with clear_and_catch_warnings() as w:
+            warnings.simplefilter("always")
+            hdr2.set_slice_times([0.1, 0])
+            assert len(w) == 1
+        # but always must be choosing sequential one first
+        assert_equal(hdr2.get_value_label('slice_code'), 'sequential decreasing')
+        # and the other direction
+        hdr2.set_slice_times([0, 0.1])
+        assert_equal(hdr2.get_value_label('slice_code'), 'sequential increasing')
+
+
     def test_intents(self):
         ehdr = self.header_class()
         ehdr.set_intent('t test', (10,), name='some score')
